pub enum Key {
Show 88 variants
ArrowDown,
ArrowLeft,
ArrowRight,
ArrowUp,
Escape,
Tab,
Backspace,
Enter,
Space,
Insert,
Delete,
Home,
End,
PageUp,
PageDown,
Copy,
Cut,
Paste,
Colon,
Comma,
Backslash,
Slash,
Pipe,
Questionmark,
OpenBracket,
CloseBracket,
Backtick,
Minus,
Period,
Plus,
Equals,
Semicolon,
Num0,
Num1,
Num2,
Num3,
Num4,
Num5,
Num6,
Num7,
Num8,
Num9,
A,
B,
C,
D,
E,
F,
G,
H,
I,
J,
K,
L,
M,
N,
O,
P,
Q,
R,
S,
T,
U,
V,
W,
X,
Y,
Z,
F1,
F2,
F3,
F4,
F5,
F6,
F7,
F8,
F9,
F10,
F11,
F12,
F13,
F14,
F15,
F16,
F17,
F18,
F19,
F20,
}Expand description
Re-export eframe types for consistency Keyboard keys.
egui usually uses logical keys, i.e. after applying any user keymap.
Variants
ArrowDown
ArrowLeft
ArrowRight
ArrowUp
Escape
Tab
Backspace
Enter
Space
Insert
Delete
Home
End
PageUp
PageDown
Copy
Cut
Paste
Colon
:
Comma
,
Backslash
‘\’
Slash
‘/’
Pipe
‘|’, a vertical bar
Questionmark
?
OpenBracket
CloseBracket
Backtick
‘`’, also known as “backquote” or “grave”
Minus
-
Period
.
Plus
+
Equals
=
Semicolon
;
Num0
Either from the main row or from the numpad.
Num1
Either from the main row or from the numpad.
Num2
Either from the main row or from the numpad.
Num3
Either from the main row or from the numpad.
Num4
Either from the main row or from the numpad.
Num5
Either from the main row or from the numpad.
Num6
Either from the main row or from the numpad.
Num7
Either from the main row or from the numpad.
Num8
Either from the main row or from the numpad.
Num9
Either from the main row or from the numpad.
A
B
C
D
E
F
G
H
I
J
K
L
M
N
O
P
Q
R
S
T
U
V
W
X
Y
Z
F1
F2
F3
F4
F5
F6
F7
F8
F9
F10
F11
F12
F13
F14
F15
F16
F17
F18
F19
F20
Implementations
Sourceimpl Key
impl Key
Sourcepub fn from_name(key: &str) -> Option<Key>
pub fn from_name(key: &str) -> Option<Key>
Converts "A" to Key::A, Space to Key::Space, etc.
Makes sense for logical keys.
This will parse the output of both Self::name and Self::symbol_or_name,
but will also parse single characters, so that both "-" and "Minus" will return Key::Minus.
This should support both the names generated in a web browser,
and by winit. Please test on both with eframe.
Sourcepub fn symbol_or_name(self) -> &'static str
pub fn symbol_or_name(self) -> &'static str
Emoji or name representing the key